@@ -1,5 +1,6 @@
 module TextBuilderDev
-  ( TextBuilder,
+  ( -- *
+    TextBuilder,
 
     -- * Accessors
     buildText,
@@ -12,9 +13,6 @@ module TextBuilderDev
     putLnToStdOut,
     putLnToStdErr,
 
-    -- * Classes
-    IsomorphicToTextBuilder (..),
-
     -- * Constructors
 
     -- ** Builder manipulators
@@ -25,6 +23,7 @@ module TextBuilderDev
 
     -- ** Textual
     text,
+    lazyText,
     string,
     asciiByteString,
     hexData,
@@ -69,6 +68,9 @@ module TextBuilderDev
     -- ** Time
     utcTimestampInIso8601,
     intervalInSeconds,
+
+    -- * Classes
+    IsomorphicToTextBuilder (..),
   )
 where
 
@@ -96,25 +98,25 @@ import qualified Data.Text.Lazy.Builder as TextLazyBuilder
 -- Evidence that there exists an unambiguous way to convert
 -- a type to and from "TextBuilder".
 --
--- Unlike typical conversion classes this class is lawful.
+-- Unlike conversion classes from other libs this class is lawful.
 -- The law is:
 --
--- @a == "fromTextBuilder" ("toTextBuilder" a)@
+-- @'fromTextBuilder' . 'toTextBuilder' = 'id'@
 --
 -- This class does not provide implicit rendering,
 -- such as from integer to its decimal representation.
--- It should already be evident that there is multiple ways of
--- how an integer can be represented in a textual form (e.g., hexadecimal).
+-- There are multiple ways of representing an integer
+-- as text (e.g., hexadecimal, binary).
 -- The non-ambiguity is further enforced by the presence of
 -- the inverse conversion.
 -- In the integer case there is no way to read it
--- from a textual form without a possibility of failing.
--- So that is enough to prove that it's not sufficient.
+-- from a textual form without a possibility of failing
+-- (e.g., when the input string cannot be parsed as an integer).
 --
 -- If you're looking for such conversion classes,
 -- this library is not a place for them,
 -- since there can be infinite amount of flavours of
--- conversions. IOW, they are context-dependent and as such
+-- conversions. They are context-dependent and as such
 -- should be defined as part of the domain.
 class IsomorphicToTextBuilder a where
   toTextBuilder :: a -> TextBuilder
@@ -133,7 +135,7 @@ instance IsomorphicToTextBuilder String where
   fromTextBuilder = Text.unpack . buildText
 
 instance IsomorphicToTextBuilder TextLazy.Text where
-  toTextBuilder = text . TextLazy.toStrict
+  toTextBuilder = lazyText
   fromTextBuilder = TextLazy.fromStrict . buildText
 
 instance IsomorphicToTextBuilder TextLazyBuilder.Builder where
@@ -175,6 +177,9 @@ instance IsString TextBuilder where
 instance Show TextBuilder where
   show = Text.unpack . buildText
 
+instance Eq TextBuilder where
+  (==) = on (==) buildText
+
 -- * Accessors
 
 -- | Get the amount of characters
@@ -363,6 +368,11 @@ text text@(C.Text array offset length) =
         B.copyI builderArray builderOffset array offset (builderOffset + length)
 #endif
 
+{-# INLINE lazyText #-}
+lazyText :: TextLazy.Text -> TextBuilder
+lazyText =
+  TextLazy.foldrChunks (mappend . text) mempty
+
 -- | String
 {-# INLINE string #-}
 string :: String -> TextBuilder
